aboutsummaryrefslogtreecommitdiff
path: root/kernel/src/filesystem/mount_table.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kernel/src/filesystem/mount_table.cpp')
-rw-r--r--kernel/src/filesystem/mount_table.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kernel/src/filesystem/mount_table.cpp b/kernel/src/filesystem/mount_table.cpp
index 4b61fb0..78ac727 100644
--- a/kernel/src/filesystem/mount_table.cpp
+++ b/kernel/src/filesystem/mount_table.cpp
@@ -31,7 +31,7 @@ namespace kernel::filesystem
auto mount_table::remove_mount(std::string_view path) -> operation_result
{
// TODO BA-FS26 check wheter something is open in this mount
// TODO BA-FS26 nearly the same code is in find_exact_mount -> refactor to avoid code duplication
auto mount_range =
std::ranges::find_last_if(m_mounts, [&](auto const & mount) { return mount->get_mount_path() == path; });
auto mount_it = mount_range.begin();
@@ -52,7 +52,7 @@ namespace kernel::filesystem
return operation_result::removed;
}
- auto mount_table::find_exact_mount(std::string_view path) const -> kstd::shared_ptr<mount>
+ auto mount_table::find_mount(std::string_view path) const -> kstd::shared_ptr<mount>
{
auto mount_range =
std::ranges::find_last_if(m_mounts, [&](auto const & mount) { return mount->get_mount_path() == path; });
@@ -31,7 +31,7 @@ namespace kernel::filesystem
{
// TODO BA-FS26 check wheter something is open in this mount
- // TODO BA-FS26 nearly the same code is in find_exact_mount -> refactor to avoid code duplication
+ // TODO BA-FS26 nearly the same code is in find_mount -> refactor to avoid code duplication
auto mount_range =
std::ranges::find_last_if(m_mounts, [&](auto const & mount) { return mount->get_mount_path() == path; });